@@ -14,7 +14,7 @@ Usage::
     client: SSOOIDCClient = boto3.client("sso-oidc")
     session_client: SSOOIDCClient = session.client("sso-oidc")
 """
-from mypy_boto3_sso_oidc.client import SSOOIDCClient as Client, SSOOIDCClient
+from mypy_boto3_sso_oidc.client import SSOOIDCClient, SSOOIDCClient as Client
 
 
 __all__ = ("Client", "SSOOIDCClient")
